import 'package:consoledoctor_common/consoledoctor_common.dart';
import 'package:consoledoctor_vanguard_http/src/vanguard_client_config.dart';
import 'package:dio/dio.dart';
import 'package:logging/logging.dart';

abstract class VanguardApiClient {

  late final Map<String, String> headers;

  final Dio dio = Dio();

  final String? path;

  late final Logger logger;
  VanguardClientConfig config;

  VanguardApiClient({required this.config, this.path, required String loggerName}) {
    logger = Logger(loggerName);

    setBaseUrl();

    dio.options.connectTimeout = const Duration(seconds: 15);
    dio.options.receiveTimeout = const Duration(seconds: 15);
    dio.options.headers = config.buildHeaders();
  }

  void setBaseUrl() {
    final clientUri = config.serverUrl;
    var baseUrl = clientUri.endsWith('/') ? clientUri : '$clientUri/';
    if (!path.isNullOrEmpty()) {
      baseUrl = '$baseUrl${path!.startsWith('/') ? path!.substring(1, path!.length -1) : path}';
    }

    dio.options.baseUrl = baseUrl;
    logger.info("Updated base url to: ${dio.options.baseUrl} for service: ${runtimeType.toString()}. Client Hashcode: $hashCode");
  }

  void updateConfig(VanguardClientConfig config) {
    this.config = config;
    setBaseUrl();
    dio.options.headers = config.buildHeaders();
  }
}