import 'package:consoledoctor_common/consoledoctor_common.dart';
import 'package:consoledoctor_vanguard_http/src/vanguard_client_config.dart';
import 'package:dio/dio.dart';

import 'vanguard_api_client.dart';

class VanguardAuthService extends VanguardApiClient implements IPinAuthService {

  VanguardAuthService(VanguardClientConfig config) : super(config: config, path: 'login/', loggerName: 'Auth');

  @override
  Future<DataResponse<AuthenticationOutcome>> authenticate(String pin) async {
    try {
      var response = await dio.get('pins/authenticate?service=${config.appName}&pin=$pin');

      if (response.statusCode == 200) {
        return DataResponse.fromJson(response.data, AuthenticationOutcome.fromJson);
      }

      throw DioException.badResponse(statusCode: response.statusCode ?? 418, requestOptions: response.requestOptions, response:response);
    } on DioException catch (e) {
      logger.severe("Failed to authenticate", e);
      return DataResponse(result: null,
          success: false,
          message: 'Failed to authenticate',
          exceptionMessage: e.message,
          innerExceptionMessage: null);
    }
  }

}